@@ -38,7 +38,8 @@
 #'   of the functionals are not a permutation, is high, this is an
 #'   indication of a poor clustering solution, as the
 #'   functionals are not clearly separated.
-#'
+#' @export
+#' @importFrom stats kmeans
 identifyMixture <- function(Func, Mu, Eta, S, centers) {
 
     K <- length(Func[1, 1, ])
@@ -90,7 +91,7 @@ identifyMixture <- function(Func, Mu, Eta, S, centers) {
     Eta_reord <- matrix(0, M, K)
     S_reord <- matrix(0, M, N)
     
-    for (m in 1:M) {
+    for (m in setdiff(1:M, m_rho)) {
         Mu_reord[m, , Rho_m[m, ]] <- Mu[m, , ]
         Eta_reord[m, Rho_m[m, ]] <- Eta[m, ]
         S_reord[m, ] <- Rho_m[m, ][S[m, ]] 
