@@ -80,7 +80,7 @@
 #'     legend("topright", legend = c("K", expression(K["+"])),
 #'            col = 1:2, lty = 1, box.lwd = 0)
 #' }
-#' 
+#' @export
 sampleLCA <- function(y, S, pi, eta, a0,
                       M, burnin, thin, Kmax,
                       G = c("MixDynamic", "MixStatic"),
@@ -102,7 +102,7 @@ sampleLCA <- function(y, S, pi, eta, a0,
     } else {
         e0 <- priorOnWeights$param$e0
         alpha <- e0 * nrow(pi)
-        log_p_e0 <- priorOnWeights$param$log_p_e0
+        log_p_e0 <- priorOnWeights$log_p_e0
     }
     s0_proposal <- priorOnWeights$param$s0_proposal
 
