@@ -96,7 +96,8 @@
 #'     legend("topright", legend = c("K", expression(K["+"])),
 #'            col = 1:2, lty = 1, box.lwd = 0)
 #' }
-#' 
+#' @export
+#' @importFrom stats dgamma rgamma rnorm
 
 sampleUniNormMixture <-
     function(y, S, mu, sigma2, eta, c0, g0, G0, C0_0, 
@@ -113,7 +114,7 @@ sampleUniNormMixture <-
     log_pK <- priorOnK$log_pK
     G <- match.arg(G)
     if (G == "MixDynamic") {
-        log_pAlpha <- priorOnWeights$param$log_pAlpha  
+        log_pAlpha <- priorOnWeights$log_pAlpha  
         a_alpha <- priorOnWeights$param$a_alpha        
         b_alpha <- priorOnWeights$param$b_alpha        
         alpha <- priorOnWeights$param$alpha
